@@ -10,28 +10,41 @@ class bcolors:
 
 
 class AppChecker:
-    def __init__(self, checks: Optional[List[Callable[[], Any]]] = None) -> None:
+    def __init__(
+        self,
+        checks: Optional[List[Callable[[], Any]]] = None,
+        silent_mode: bool = False,
+    ) -> None:
         self.checks: List[Callable[[], Any]] = []
-        self.spinner: Halo = Halo(text="Loading", spinner="dots")
+        self.silent_mode = silent_mode
+        self.spinner: Halo = Halo(
+            text="Loading", spinner="dots", enabled=(not self.silent_mode)
+        )
         self.success: int = 0
         self.failure: int = 0
+        self.results: List[dict] = []
 
     def register_check(self, func: Callable[[], Any]) -> Callable[[], Any]:
-        """Метод для регистрации функции проверки."""
         self.checks.append(func)
         return func
 
+    def log(self, message: str = "") -> None:
+        if not self.silent_mode:
+            print(message)
+
     async def run_checks(self) -> None:
         self.display_message(self.on_center("check starts"))
-        print(f"collected {len(self.checks)} items")
-        print()
+        self.log(f"collected {len(self.checks)} items")
+        self.log()
         for check in self.checks:
             result: Optional[bool] = False
             name: str = check.__name__
 
-            print(f"Starting {name}...")
+            self.log(f"Starting {name}...")
             result = await self.load_with_halo(check)
 
+            self.results.append({"name": name, "success": result})
+
             if result is True:
                 self.spinner.succeed(f"[SUCCESS] {name}")
                 self.success += 1
@@ -42,7 +55,7 @@ class AppChecker:
         self.display_results()
 
     async def load_with_halo(self, check_func: Callable[[], Any]) -> bool:
-        with Halo(text="Loading", spinner="dots"):
+        with Halo(text="Loading", spinner="dots", enabled=(not self.silent_mode)):
             try:
                 result: bool = await check_func()
             except Exception as e:
@@ -69,7 +82,7 @@ class AppChecker:
             self.display_startup_message("Some checks failed.")
 
     def display_startup_message(self, message: str) -> None:
-        print(message)
+        self.log(message)
 
     def set_color(self, message: str, color: Optional[str] = None) -> str:
         if color:
@@ -84,9 +97,9 @@ class AppChecker:
         terminal_width: int = shutil.get_terminal_size().columns
         dashes: str = "-" * terminal_width
 
-        print(self.set_color(dashes, color))
-        print(f"{message}")
-        print(self.set_color(dashes, color))
+        self.log(self.set_color(dashes, color))
+        self.log(f"{message}")
+        self.log(self.set_color(dashes, color))
 
     def check_health(self, func: Callable[[], Any]) -> Callable[[], Any]:
 
@@ -95,9 +108,15 @@ class AppChecker:
             try:
                 return await func(*args, **kwargs)
             except Exception as e:
-                print()
-                print(e)
+                self.log()
+                self.log(e)
                 return False
 
         self.register_check(wrapper)
         return wrapper
+
+    def get_results(self) -> List[dict]:
+        return self.results
+
+    def clear_results(self) -> None:
+        self.results.clear()
